@@ -8,6 +8,8 @@ if type alr; then
 
     if [ x$1 == x ];
        echo "you must specify the install directory with 'install.sh <dir>'"
+       # FIXME: default prefix to $HOME/.local
+       # https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
        return 1
     fi
     # IMPROVEME: when alr supports install, use that
@@ -23,9 +25,6 @@ elif type gprbuild; then
 
     if [ -d ../wisi-4.1.? ]; then
         WISI_DIR=`ls -d ../wisi-4.1.?`
-    else
-        # try devel version
-        WISI_DIR=`find .. -type d -name "wisi-4.1.beta*"`
     fi
 
     gprinstall -f -p -P ada_mode_wisi_parse.gpr -aP $WISI_DIR --install-name=ada_mode_wisi_parse $1 
